The paths thermal_zone%d and cooling_device%d are not intuitive and the
numbers are subject to change due to device tree change. This usually
leads to tree traversal in userspace code.
The patch creates `tz-by-name' and `cdev-by-name' for thermal zone and
cooling_device respectively.

Signed-off-by: Wei Wang <w...@google.com>
---
 drivers/thermal/thermal_core.c | 23 +++++++++++++++++++++--
 1 file changed, 21 insertions(+), 2 deletions(-)

diff --git a/drivers/thermal/thermal_core.c b/drivers/thermal/thermal_core.c
index d4481cc8958f..0ff8fb1d7b0a 100644
--- a/drivers/thermal/thermal_core.c
+++ b/drivers/thermal/thermal_core.c
@@ -22,6 +22,7 @@
 #include <net/netlink.h>
 #include <net/genetlink.h>
 #include <linux/suspend.h>
+#include <linux/kobject.h>
 
 #define CREATE_TRACE_POINTS
 #include <trace/events/thermal.h>
@@ -46,6 +47,8 @@ static DEFINE_MUTEX(poweroff_lock);
 
 static atomic_t in_suspend;
 static bool power_off_triggered;
+static struct kobject *cdev_link_kobj;
+static struct kobject *tz_link_kobj;
 
 static struct thermal_governor *def_governor;
 
@@ -954,7 +957,7 @@ __thermal_cooling_device_register(struct device_node *np,
        struct thermal_zone_device *pos = NULL;
        int result;
 
-       if (type && strlen(type) >= THERMAL_NAME_LENGTH)
+       if (!type || !type[0] || strlen(type) >= THERMAL_NAME_LENGTH)
                return ERR_PTR(-EINVAL);
 
        if (!ops || !ops->get_max_state || !ops->get_cur_state ||
@@ -989,9 +992,15 @@ __thermal_cooling_device_register(struct device_node *np,
                return ERR_PTR(result);
        }
 
        /* Add 'this' new cdev to the global cdev list */
        mutex_lock(&thermal_list_lock);
        list_add(&cdev->node, &thermal_cdev_list);
+       if (!cdev_link_kobj)
+               cdev_link_kobj = kobject_create_and_add("cdev-by-name",
+                                               cdev->device.kobj.parent);
+       if (!cdev_link_kobj || sysfs_create_link(cdev_link_kobj,
+                                               &cdev->device.kobj, cdev->type))
+               dev_err(&cdev->device, "Failed to create cdev-by-name link\n");
        mutex_unlock(&thermal_list_lock);
 
        /* Update binding information for 'this' new cdev */
@@ -1157,6 +1166,8 @@ void thermal_cooling_device_unregister(struct 
thermal_cooling_device *cdev)
                        }
                }
        }
+       if (cdev_link_kobj)
+               sysfs_remove_link(cdev_link_kobj, cdev->type);
 
        mutex_unlock(&thermal_list_lock);
 
@@ -1340,6 +1351,12 @@ thermal_zone_device_register(const char *type, int 
trips, int mask,
 
        mutex_lock(&thermal_list_lock);
        list_add_tail(&tz->node, &thermal_tz_list);
+       if (!tz_link_kobj)
+               tz_link_kobj = kobject_create_and_add("tz-by-name",
+                                               tz->device.kobj.parent);
+       if (!tz_link_kobj || sysfs_create_link(tz_link_kobj,
+                                               &tz->device.kobj, tz->type))
+               dev_err(&tz->device, "Failed to create tz-by-name link\n");
        mutex_unlock(&thermal_list_lock);
 
        /* Bind cooling devices for this zone */
@@ -1411,6 +1428,8 @@ void thermal_zone_device_unregister(struct 
thermal_zone_device *tz)
                        }
                }
        }
+       if (tz_link_kobj)
+               sysfs_remove_link(tz_link_kobj, tz->type);
 
        mutex_unlock(&thermal_list_lock);
 
@@ -989,9 +992,15 @@ __thermal_cooling_device_register(struct device_node *np,
        }
 
-       /* Add 'this' new cdev to the global cdev list */
+       /* Add 'this' new cdev to the global cdev list and create link*/
        mutex_lock(&thermal_list_lock);
        list_add(&cdev->node, &thermal_cdev_list);
-- 
2.23.0.700.g56cf767bdb-goog

Reply via email to